To install the stable version from PyPI:
```
pip install manyq
```


To install (or reinstall) directly from the files: 
```
python setup.py install --user
```


To use (see the example folder for more):
```
import manyq as mq

mq.initQreg(2,1)

....

```
